@@ -6,8 +6,8 @@
 ;; Author: Phil Hagelberg, Cornelius Mika, Campbell Barton
 ;; Maintainer: Campbell Barton <ideasman42@gmail.com>
 ;; URL: https://codeberg.org/ideasman42/emacs-idle-highlight-mode
-;; Package-Version: 20251030.2359
-;; Package-Revision: e3f16de93ece
+;; Package-Version: 20251126.1130
+;; Package-Revision: 4f5183c480c3
 ;; Created: 2008-05-13
 ;; Keywords: convenience
 ;; EmacsWiki: IdleHighlight
@@ -210,7 +210,7 @@ Where RANGES is an unordered list of (min . max) cons cells."
 (defun idle-highlight--check-word (target)
   "Return non-nil when TARGET should not be excluded."
   (declare (important-return-value t))
-  (not
+  (null
    (cond
     ((functionp idle-highlight-exceptions)
      (funcall idle-highlight-exceptions target))
@@ -360,7 +360,7 @@ should be the result of `idle-highlight--word-at-point-args'."
             (setq target-args (idle-highlight--word-at-point-args)))
 
           (pcase-let ((`(,target . ,target-range) target-args))
-            (when (and force-all (not (eq buf buf-current)))
+            (when (and force-all (null (eq buf buf-current)))
               (setq target-range nil))
             (idle-highlight--word-at-point-highlight target target-range visible-ranges))
           ;; Once complete, this is no longer dirty.
@@ -440,17 +440,17 @@ should be the result of `idle-highlight--word-at-point-args'."
          ;; Not already enabled.
          (not (bound-and-true-p idle-highlight-mode))
          ;; Not in the mini-buffer.
-         (not (minibufferp))
+         (null (minibufferp))
          ;; Not a special mode (package list, tabulated data ... etc)
          ;; Instead the buffer is likely derived from `text-mode' or `prog-mode'.
-         (not (derived-mode-p 'special-mode))
+         (null (derived-mode-p 'special-mode))
          ;; Not explicitly ignored.
-         (not (memq major-mode idle-highlight-ignore-modes))
+         (null (memq major-mode idle-highlight-ignore-modes))
          ;; Optionally check if a function is used.
          (or (null idle-highlight-global-ignore-buffer)
              (cond
               ((functionp idle-highlight-global-ignore-buffer)
-               (not (funcall idle-highlight-global-ignore-buffer (current-buffer))))
+               (null (funcall idle-highlight-global-ignore-buffer (current-buffer))))
               (t
                nil))))
     (idle-highlight-mode 1)))
